@@ -8,7 +8,7 @@ from tornado import ioloop
 from tornado.concurrent import Future
 
 
-version_tuple = (0, 5)
+version_tuple = (0, 6)
 
 version = '.'.join(map(str, version_tuple))
 """Current version of Toro."""
@@ -408,7 +408,7 @@ class Queue(object):
         if self.maxsize == 0:
             return False
         else:
-            return self.qsize() == self.maxsize
+            return self.maxsize <= self.qsize()
 
     def put(self, item, deadline=None):
         """Put an item into the queue. Returns a Future.
@@ -433,7 +433,7 @@ class Queue(object):
             getter.set_result(self._get())
             future.set_result(None)
         else:
-            if self.maxsize and self.maxsize == self.qsize():
+            if self.maxsize and self.maxsize <= self.qsize():
                 self.putters.append((item, future))
             else:
                 self._put(item)
@@ -453,7 +453,7 @@ class Queue(object):
 
             self._put(item)
             getter.set_result(self._get())
-        elif self.maxsize and self.maxsize == self.qsize():
+        elif self.maxsize and self.maxsize <= self.qsize():
             raise Full
         else:
             self._put(item)
